/*
 *  Gnome Character Map
 *  menus.h - Menus for the main window
 *
 *  Copyright (C) Hongli Lai
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _MENUS_H_
#define _MENUS_H_

#include <gnome.h>

extern GnomeUIInfo characters_menu[];
extern GnomeUIInfo edit_menu[];
extern GnomeUIInfo help_menu[];
extern GnomeUIInfo menubar[];
extern GnomeUIInfo toolbar[];

#endif /* _MENUS_H_ */
